@@ -22,9 +22,9 @@ from ask_sdk_model.request import Request
 
 
 if typing.TYPE_CHECKING:
-    from typing import Dict, List, Optional, Union
+    from typing import Dict, List, Optional, Union, Any
     from datetime import datetime
-    from ask_sdk_model.services.list_management.list_body import ListBody
+    from ask_sdk_model.services.list_management.list_body import ListBody as ListBody_9725fe55
 
 
 class ListCreatedEventRequest(Request):
@@ -66,7 +66,7 @@ class ListCreatedEventRequest(Request):
     supports_multiple_types = False
 
     def __init__(self, request_id=None, timestamp=None, locale=None, body=None, event_creation_time=None, event_publishing_time=None):
-        # type: (Optional[str], Optional[datetime], Optional[str], Optional[ListBody], Optional[datetime], Optional[datetime]) -> None
+        # type: (Optional[str], Optional[datetime], Optional[str], Optional[ListBody_9725fe55], Optional[datetime], Optional[datetime]) -> None
         """
 
         :param request_id: Represents the unique identifier for the specific request.
